;;; howm-version.el --- Wiki-like keyword jump between files
;;; -*- Emacs-Lisp -*-
;;; @configure_input@

(provide 'howm-version)
(defconst howm-version "1.3.4")
(defconst howm-en-dir "~endir~")
(defconst howm-ja-dir "~jadir~")

;;; howm-version.el ends here
